#
# spec file for package osdlyrics
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osdlyrics
Version:        0.5.14
Release:        1.1
Summary:        A third-party lyrics display program
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Visualization
URL:            https://github.com/osdlyrics/osdlyrics
Source0:        https://github.com/osdlyrics/osdlyrics/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.appdata.xml
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  gnome-common
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appindicator-0.1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sqlite3)
Requires:       gtk2
Requires:       python3-chardet
Requires:       python3-future
Requires:       python3-pycurl
Requires:       sqlite3
Recommends:     %{name}-lang
Recommends:     python3-%{name}

%description
OSD Lyrics is a lyrics show compatible with various media players. It is not a
plugin but a standalone program. OSD Lyrics shows lyrics on your desktop, in the
style similar to KaraOK. It also provides another displaying style, in which
lyrics scroll from bottom to top. OSD Lyrics can download lyrics from the
network automatically.

%package -n python3-%{name}
Summary:        Python module for osdlyrics
Group:          Productivity/Multimedia/Sound/Visualization
Requires:       %{name} = %{version}
Obsoletes:      python-%{name} <= %{version}

%description -n python3-osdlyrics
This package contains python3 module for osdlyrics

%lang_package

%prep
%setup -q -n %{name}-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure  --enable-appindicator \
            PYTHON=/usr/bin/python3

%make_build

%install
%make_install
install -d %{buildroot}%{_datadir}/metainfo
install -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/metainfo

%suse_update_desktop_file %{name}

%find_lang %{name}
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{python3_sitelib}
%fdupes %{buildroot}%{_libdir}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-create-lyricsource
%{_bindir}/%{name}-daemon
%{_libdir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/%{name}/
%{_datadir}/dbus-1/services/org.%{name}.*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml

%files -n python3-%{name}
%{python3_sitelib}/%{name}

%files lang -f %{name}.lang

%changelog
* Tue Jul 18 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.14
  * Fix Chinese encodings
  * Fix proxy-password config
  * Fix sources in the default search
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.13:
  * Second attempt on inferring the artist from the title when
    the former is invalid.
* Mon Oct 17 2022 Steve Kowalik <steven.kowalik@suse.com>
- Change BuildRequires on python to be python3.
* Thu Sep 15 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.12
  * Fix the close button focus behavior
  * Fix the behavior of the "OSD/visible" config
  * Fix the behavior of hiding the OSD when playter is stopped
  * Fix position update when seeking
  * fix show/hide glitch
  * save/restore window position
  * fix content-reproducibility
* Mon Feb 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.10
  * Add translated Netease as lyrics source
  * Addressed gtk deprecation warnings during compile time
  * Treat obsolete messages
  * Treat C-compile warnings
* Mon Nov 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.7
  * Netease: Show more results
  * Add Megalobiz
  * Remove ViewLyrics
  * Remove LRC123
  * Add Subtitles4Songs
* Tue Oct 26 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.5
  * Fix D-Bus race-condition
  * Enhance metadata parsing
  * Update romanian translation
* Fri Jun 12 2020 Hillwood Yang <hillwood@opensuse.org>
- Update to 0.5.5RC2
  * Fix python logging
* Mon Jun  1 2020 Hillwood Yang <hillwood@opensuse.org>
- Rename osdlyrics-appdata.xml to osdlyrics.appdata.xml
* Sun Jan  5 2020 Hillwood Yang <hillwood@opensuse.org>
- Change appdata install path.
* Wed Jan  1 2020 Hillwood Yang <hillwood@opensuse.org>
- Drop xmms2 support
* Tue May 14 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.5.5RC1
  * Fix autoreconf with "foreign" flag
  * Upgrade PyGObject from 2 to 3
- Use python3.
* Tue Oct  2 2018 hillwood@opensuse.org
- Update version to 0.4.3+git20180723.
  * Add netease source
  * Fix bugs
* Tue Sep 25 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repetition of program name.
* Mon Sep 24 2018 astieger@suse.com
- License is GPL-3.0-or-later
* Mon Sep 24 2018 hillwood@opensuse.org
- Fix boo#1109453. Set Requires tag for python-curl and python-chardet
* Sun Dec 17 2017 hillwood@opensuse.org
- Update appdata install.
* Tue Nov 28 2017 hillwood@opensuse.org
- Enable appindicator.
- Update %%suse_update_desktop_file Macro.
* Sun Nov 26 2017 hillwood@opensuse.org
- Add appdata.
* Thu Nov 23 2017 hillwood@opensuse.org
- Update to 0.4.3+git8661927
  * Fixed lyric download failed form Xiami source
  * Fix ensure_utf8() after
  * Make decode_by_charset work under both Python 2 and 3
  * Make ensure_unicode and ensure_utf8 no-op under Python 3
  * Make ElementTree produce a normal Unicode string
  * Use a key function instead of cmp in sort()
  * PEP8 fixes and Python3 compatibility for daemon/main.py
  * Skip the daemon's name when detecting MPRIS2 players.
  * Many features update.
- Drop osdlyrics-includes.patch, merged by upstream
- Update OSD Lyrics' home URL
- Update description.
- Drop Obsoletes tags.
- Use %%fdupes macro.
* Fri Nov  6 2015 hillwood@linuxfans.org
- Fix build in Leap: disable xmms2
* Fri Nov 16 2012 aj@suse.de
- Fix missing include (add patch patches/osdlyrics-includes.patch).
* Mon Jun  4 2012 hillwood@linuxfans.org
- update to 0.4.3
  * Player support:
  - Add cmus support, thanks to alepulver (not enable)
  * Bug fix:
  - Dir is not closed in _prepend_subdirs (ol_app_info.c)
  - Show player chooser if connected player quits in 1 minute
* Thu Mar  1 2012 hillwood@linuxfans.org
- add xmms2 spport
- split the translations in a lang subpackage
- rename patch file
- fixed some RPMLINT report warnings
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Jan 19 2012 hillwood@linuxfans.org
- update to 0.4.2
  * UI improvements:
  - Player choose dialog redesigned
  - Fade out on the edge of lyric text in OSD mode if it is too long
  - Drag-to-seek in scrolling mode
  * Player support:
  - Bring back support for Rhythmbox prior to 0.13
  - Support RhythmCat
  - Auto-detect the launch command for Audacious 2 and 3
  - Do not require root privilege to launch MPD
  * Bug fixes:
  - Blurring in OSD mode will not cause a frame around lyrics
  - Fix compilation issue in BDS systems.
  - Fix track duration in MPRIS support
  - Deal with player launch commands with %%f or %%U as arguments
  - ttPlayer engine can search lyrics with ' in the title
  - CUE sheets are supported now
  - Don't show invalid search result of Xiami engine
* Fri Dec  9 2011 hillwood@linuxfans.org
- Fix %%post* , change the license to "GPL-3.0" .
* Sun Nov 13 2011 hillwood@linuxfans.org
- support openSUSE 12.1
* Mon Jul 18 2011 hillwood@linuxfans.org
- Uptate to 0.4.1
- Choose player if no supported player running on launch
- Outline blur on OSD mode
- Support all MPRIS-compatible players
- New lyrics search site: xiami.com
- Fix ttPlayer search
- Search lyrics from more than one sites
- All files with the name of osd-lyrics are replaced to osdlyrics
* Sat Jul  9 2011 hillwood@linuxfans.org
- rewrite description.
* Mon Jun 27 2011 hillwood@linuxfans.org
- rename the package name.
* Sun Jun 26 2011 hillwood@linuxfans.org
- add support for Fedora and Mandriva.
* Fri Jun 10 2011 hillwood@linuxfans.org
- Uptate to 0.4.0
* Sun May 29 2011 hillwood@linuxfans.org
- Uptate to 0.4.0b1
* Wed Apr 20 2011 hillwood@linuxfans.org
- Inital package for opensuse and SLE.
